pub struct MouseInputReport {
pub movement_x: Option<i64>,
pub movement_y: Option<i64>,
pub scroll_v: Option<i64>,
pub scroll_h: Option<i64>,
pub pressed_buttons: Option<Vec<u8>>,
pub position_x: Option<i64>,
pub position_y: Option<i64>,
/* private fields */
}Expand description
MouseReport gives the relative movement of the mouse and currently
pressed buttons. Relative means the movement seen between the previous
report and this report. The client is responsible for tracking this and
converting it to absolute movement.
At least one of the fields below must be present.
Fields
movement_x: Option<i64>Relative X positional displacement.
Optional. Present iff the mouse reports relative X movement.
Must not co-exist with position_x and position_y.
movement_y: Option<i64>Relative Y positional displacement.
Optional. Present iff the mouse reports relative Y movement.
Must not co-exist with position_x and position_y.
scroll_v: Option<i64>Relative vertical scrolling displacement.
Optional. Present iff the mouse reports relative vertical scroll.
scroll_h: Option<i64>Relative horizontal scrolling displacement.
Optional. Present iff the mouse reports relative horizontal scroll.
A list of currently pressed buttons.
Optional. Empty iff no button is pressed. Present iff the mouse reports button state.
position_x: Option<i64>The position of X. The main use of position is from virtual mice like over VNC.
Optional. Present iff the mouse reports absolute X position.
Must not co-exist with movement_x and movement_y.
position_y: Option<i64>The position of Y. The main use of position is from virtual mice like over VNC.
Optional. Present iff the mouse reports absolute Y position.
Must not co-exist with movement_x and movement_y.