pub struct SensorFeatureDescriptor {
pub report_interval: Option<Axis>,
pub sensitivity: Option<Vec<SensorAxis>>,
pub supports_reporting_state: Option<bool>,
pub threshold_high: Option<Vec<SensorAxis>>,
pub threshold_low: Option<Vec<SensorAxis>>,
pub sampling_rate: Option<Axis>,
pub report_id: Option<u8>,
/* private fields */
}Expand description
Describes the format of the sensor’s feature report. Feature reports can be requested from the sensor, or sent to the sensor.
At least one of the fields below must be present.
Fields
report_interval: Option<Axis>Valid range of the reporting interval for the given SensorType.
Optional. Present iff sensor supports getting/setting the reporting interval.
sensitivity: Option<Vec<SensorAxis>>Valid range of the sensitivity for the given SensorType.
Optional. Present iff sensor supports getting/setting the sensitivity.
supports_reporting_state: Option<bool>True iff SensorFeatureReport supports setting/getting the
SensorReportingState.
Optional. Present iff sensor supports getting/setting the reporting state.
threshold_high: Option<Vec<SensorAxis>>Valid range of the high threshold values for the given SensorType.
Optional. Present iff sensor supports getting/setting the high threshold values.
threshold_low: Option<Vec<SensorAxis>>Valid range of the low threshold values for the given SensorType.
Optional. Present iff sensor supports getting/setting the low threshold values.
sampling_rate: Option<Axis>Valid range of sampling rates this sensor supports.
Optional. Present iff sensor supports getting/setting the sampling rate.
report_id: Option<u8>A sensor may have multiple feature descriptors of the same type. Reports with the same report ID are associated with this descriptor.
Required iff the sensor has more than one feature descriptors.