pub type ConsumerControlButton = ConsumerControlButton;Aliased Type
pub enum ConsumerControlButton {
VolumeUp,
VolumeDown,
Pause,
FactoryReset,
MicMute,
Reboot,
CameraDisable,
Function,
Power,
// some variants omitted
}Variants
VolumeUp
This button represents increasing volume.
VolumeDown
This button represents decreasing volume.
Pause
This button represents pausing.
FactoryReset
This button represents factory resetting the host.
MicMute
This button represents muting the microphone on the host.
Reboot
This button represents rebooting the host.
CameraDisable
This button represents disabling the camera on the host.
Function
This button represents a function.
Power
This button represents a power button.