pub struct MouseInputDescriptor {
pub movement_x: Option<Axis>,
pub movement_y: Option<Axis>,
pub scroll_v: Option<Axis>,
pub scroll_h: Option<Axis>,
pub buttons: Option<Vec<u8>>,
pub position_x: Option<Axis>,
pub position_y: Option<Axis>,
/* private fields */
}Expand description
Describes the format of the input report that will be sent from the mouse to the device.
At least one of the fields below must be present.
Fields
movement_x: Option<Axis>The range of relative X movement.
Optional. Present iff the mouse reports relative X movement.
movement_y: Option<Axis>The range of relative Y movement.
Optional. Present iff the mouse reports relative Y movement.
scroll_v: Option<Axis>The range of relative vertical scroll.
Optional. Present iff the mouse reports relative vertical scroll.
scroll_h: Option<Axis>The range of relative horizontal scroll.
Optional. Present iff the mouse reports relative horizontal scroll.
IDs of the mouse buttons.
Optional. Present iff the mouse reports button state. Must be non-empty if present.
position_x: Option<Axis>The range of the position of X. The main use of position is from virtual mice like over VNC.
Optional. Present iff the mouse reports absolute X position.
position_y: Option<Axis>The range of the position of Y. The main use of position is from virtual mice like over VNC.
Optional. Present iff the mouse reports absolute Y position.